﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System.Drawing;
using System.ComponentModel;

namespace _101919
{
    class MyDraw: IUIElementDrawFilter, INotifyPropertyChanged

    {

        public enum BorderElements { None=-1 , SummaryFooterCaption = 1, FixedSummaryArea = 2, FreeFormSummaryArea = 4, SummaryValue = 8, SummaryFooter = SummaryValue | SummaryFooterCaption | FixedSummaryArea | FreeFormSummaryArea };

        BorderElements skipBordersOf = BorderElements.SummaryValue;
        List<Type> types = new List<Type> { typeof(UIElementDrawParams) };

        [DefaultValue(typeof(BorderElements),"SummaryValue")]
        public BorderElements SkipBordersOf
        {
            get { return skipBordersOf; }
            set
            {
                skipBordersOf = value;
                Notify("SkipBordersOf");
                types.Clear();
                if (value == BorderElements.None)
                    return;
                foreach (BorderElements e in Enum.GetValues(typeof(BorderElements)))
                {
                    if (value.HasFlag(e))
                    {
                        switch (e)
                        {
                            case BorderElements.SummaryValue:
                                types.Add(typeof(SummaryValueUIElement));
                                break;
                            case BorderElements.SummaryFooterCaption:
                                types.Add(typeof(SummaryFooterCaptionUIElement));
                                break;
                            case BorderElements.FreeFormSummaryArea:
                                types.Add(typeof(FreeFormSummaryAreaUIElement));
                                break;
                            case BorderElements.FixedSummaryArea:
                                types.Add(typeof(FixedSummaryAreaUIElement));
                                break;
                            case BorderElements.SummaryFooter:
                                types.Add(typeof(SummaryFooterUIElement));
                                    break;
                        }
                    }

                }
            }
        }


        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            if (drawPhase == DrawPhase.BeforeDrawBackColor)
            {
                //Draw background color manually, because it covers the borther of the parent element
                Rectangle rect = drawParams.Element.Rect;
                int elindex = drawParams.Element.Parent.ChildElements.IndexOf(drawParams.Element);
                int xOffset = elindex == 0 ? 1 : 0;
                rect.Offset(xOffset, 1);
                int widtOffset = elindex == drawParams.Element.Parent.ChildElements.Count - 1 ? -2 : 0;
                rect.Width += widtOffset;
                rect.Height += -2;
                drawParams.DrawBackColor(rect);

            }
            return true;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (types.Contains(drawParams.Element.GetType()))
                return DrawPhase.BeforeDrawBorders | DrawPhase.BeforeDrawBackColor;
            return DrawPhase.None;
        }

        public event System.ComponentModel.PropertyChangedEventHandler PropertyChanged;

        private void Notify(string property)
        {
            if (PropertyChanged != null)
                PropertyChanged.Invoke(this, new System.ComponentModel.PropertyChangedEventArgs(property));
        }
    }
}
